@@ -95,7 +95,7 @@ impl Terminal {
     /// print to stdout with newline
     pub fn println<T: std::fmt::Display>(&self, content: T) -> Result<(), Error> {
         let mut handle = self.stdo.lock();
-        match writeln!(handle, "{}\n", content) {
+        match writeln!(handle, "{}", content) {
             Ok(_) => Ok(()),
             Err(_) => Err(Error::new(ErrorKind::Other, "problems writing to stdout")),
         }
@@ -113,7 +113,7 @@ impl Terminal {
     /// print to stderr with newline
     pub fn eprintln<T: std::fmt::Display>(&self, content: T) -> Result<(), Error> {
         let mut handle = self.stde.lock();
-        match writeln!(handle, "{}\n", content) {
+        match writeln!(handle, "{}", content) {
             Ok(_) => Ok(()),
             Err(_) => Err(Error::new(ErrorKind::Other, "problems writing to stdout")),
         }
@@ -198,12 +198,20 @@ impl Terminal {
     /// *`x`: the x position to move to
     /// *`y`: the y position to move to
     pub fn set_cursor(&self, x: usize, y: usize) -> Result<(), Error> {
-        match self.print(format!("\x1b[{};{}H", x, y)) {
-            Ok(()) => Ok(()),
-            Err(e) => Err(e),
-        }
+        self.print(format!("\x1b[{};{}H", x, y))
     }
 
+    /// set the cursors x position
+    /// # Arguments
+    /// *`x`: the x position to move to
+    pub fn set_cursor_x(&self, x: usize) -> Result<(), Error> {
+        self.print(format!("\x1b[{}G", x))
+    }
+
+    // }}}
+
+    // display control: {{{
+
     /// clear the current line
     pub fn clear_line(&self) -> Result<(), Error> {
         self.print("\x1b[2K")
@@ -220,6 +228,7 @@ impl Terminal {
     }
 
     // }}}
+
 }
 
 impl Default for Terminal {
